@@ -27,7 +27,7 @@ from venues import NewVenueWindow, VenueListWindow
 from foursquare import Cache
 from locationProviders import LocationProviderSelector, LocationProvider
 from threads import VenueProviderThread, UserUpdaterThread, ImageCacheThread, UpdateSelf, VenueSearchThread
-from custom_widgets import SignalEmittingValueButton, CategorySelector, UberSquareWindow
+from custom_widgets import SignalEmittingValueButton, CategorySelector, UberSquareWindow, Title
 from users import UserListWindow
 from about import AboutDialog
 
@@ -41,10 +41,20 @@ class Profile(QWidget):
         self.textLabel = QLabel()
         self.__updateInfo(True)
 
+        name = ""
+        if u'firstName' in self.user:
+            name += self.user[u'firstName'] + " "
+        if u'lastName' in self.user:
+            name += self.user[u'lastName']
+        name += ""
+
+        self.nameTitle = QLabel("<b>" + name + "</b>")
+
         profileLayout = QGridLayout()
         self.setLayout(profileLayout)
-        profileLayout.addWidget(self.photo_label, 0, 0)
-        profileLayout.addWidget(self.textLabel, 0, 1, 1, 2)
+        profileLayout.addWidget(self.photo_label, 0, 0, 2, 1)
+        profileLayout.addWidget(self.nameTitle, 0, 1, 1, 2)
+        profileLayout.addWidget(self.textLabel, 1, 1, 1, 2)
 
         #profileLayout.addWidget(QLabel("current user location"), 1, 0, 1, 3)
 
@@ -66,18 +76,12 @@ class Profile(QWidget):
         if not initial:
             QMaemo5InformationBox.information(self, "Stats updated!", 1500)
             self.user = foursquare.get_user("self", foursquare.CacheOrGet)[u'user']
-        name = "<b>"
-        if u'firstName' in self.user:
-            name += self.user[u'firstName'] + " "
-        if u'lastName' in self.user:
-            name += self.user[u'lastName']
-        name += "</b>"
 
         badges = str(self.user[u'badges'][u'count']) + " badges"
         mayorships = str(self.user[u'mayorships'][u'count']) + " mayorships"
         checkins = str(self.user[u'checkins'][u'count']) + " checkins"
 
-        text = name + "<p>" + badges + "<br>" + mayorships + "<br>" + checkins
+        text = badges + "<br>" + mayorships + "<br>" + checkins
         self.textLabel.setText(text)
 
         self.photo = QImage(foursquare.image(self.user[u'photo']))
@@ -311,8 +315,9 @@ class SettingsDialog(UberSquareWindow):
 
         broadcast = foursquare.config_get("broadcast")
         if broadcast:
-            self.tw.setChecked("twitter" in broadcast)
-            self.fb.setChecked("facebook" in broadcast)
+            if not ", " in broadcast:
+                self.tw.setChecked("twitter" in broadcast)
+                self.fb.setChecked("facebook" in broadcast)
 
         self.saveButton = QPushButton("Save")
         self.connect(self.saveButton, SIGNAL("clicked()"), self.save)
@@ -325,9 +330,9 @@ class SettingsDialog(UberSquareWindow):
     def save(self):
         broadcast = "public"
         if self.tw.isChecked():
-            broadcast += ", twitter"
+            broadcast += ",twitter"
         if self.fb.isChecked():
-            broadcast += ", facebook"
+            broadcast += ",facebook"
 
         foursquare.config_set("broadcast", broadcast)
         self.close()
